@@ -51,11 +51,13 @@ class NoteSaver():
 		return now.strftime("%Y-%m-%d-%H:%M:%S")
 
 
-	def gen_id_notes(self, notes):
+	def gen_id_notes(self, notes, log=True):
 		self.ns = {}
 		count = 1
 		for i in notes:
 			self.ns[count] = i
+			if log:
+				print(count, i.split("--")[1].split(".txt")[0])
 			count+=1
 
 
@@ -74,7 +76,7 @@ class NoteSaver():
 				self.gen_id_notes(notes)
 
 		elif args.command == "r":
-			self.gen_id_notes(self.fetch_all_notes())
+			self.gen_id_notes(self.fetch_all_notes(), False)
 			id = input("Type ID of the notes. If you don't know, in command, type l")
 
 			try:
@@ -92,7 +94,3 @@ class NoteSaver():
 			link = self.save_note_online(f"{self.current_date()}--{title}", note)
 			print(f"Done! You can also access your note online at {link}")
 
-
-if __name__ == "__main__":
-    n = NoteSaver()
-    n.cli()
\ No newline at end of file
